@@ -7,7 +7,6 @@ test_that("pharmr can use pharmpy transformations", {
 
   model <- load_example_model('pheno')
   add_individual_parameter(model, 'MAT')
-  update_source(model)
-  
-  expect_match(toString(model), 'POP_MAT')
+
+  expect_match(model$model_code, 'POP_MAT')
 })
